@@ -151,6 +151,7 @@ class UKJson:
 
     def __init__(self, model: Model, pool: Pool, solution: Solution):
         self._pool: Pool = pool
+        self._model: Model = model
         self._solution: Solution = solution
 
     def _cycle(self, exchange: Exchange):
@@ -165,20 +166,39 @@ class UKJson:
             else:
                 inner_obj["p"] = donor.recipient.id
             target_v = exchange[(ind + 1) % len(exchange)]
-            recipient = target_v.donor.recipient
-            bonus, tb = UK_age_score(donor, target_v.donor)
-            transplants = [t for t in donor.transplants() if t.recipient == recipient]
-            assert len(transplants) == 1
-            transplant = transplants[0]
-            inner_obj["tb"] = tb
-            inner_obj["dif"] = bonus
-            inner_obj["s"] = transplant.weight
-            total_weight += tb + bonus + transplant.weight
-            desired = set([donor.recipient, recipient])
-            for backarc in exchange.backarc_exchanges_uk():
-                if set(backarc.all_recipients()) == desired:
-                    if len(backarc) == 2:  # 2 vertices in the "backarc exchange"
-                        inner_obj["b"] = backarc.id
+            if target_v.donor.NDD:
+                inner_obj["tb"] = 0
+                inner_obj["dif"] = 0
+                inner_obj["s"] = 0
+                desired = set([donor.recipient])
+            else:
+                recipient = target_v.donor.recipient
+                bonus, tb = UK_age_score(donor, target_v.donor)
+                transplants = [
+                    t for t in donor.transplants() if t.recipient == recipient
+                ]
+                assert len(transplants) == 1
+                transplant = transplants[0]
+                inner_obj["tb"] = tb
+                inner_obj["dif"] = bonus
+                inner_obj["s"] = transplant.weight
+                total_weight += tb + bonus + transplant.weight
+                if donor.NDD:
+                    desired = set([recipient])
+                else:
+                    desired = set([donor.recipient, recipient])
+            if len(exchange) == 3:
+                # Search for a backarc only in exchanges with 3 vertices
+                best_score = -1
+                # If there are multiple potential backarcs, we want the one
+                # with the best score
+                for backarc in exchange.backarc_exchanges_uk():
+                    if set(backarc.all_recipients()) == desired:
+                        if len(backarc) == 2:  # 2 vertices in the "backarc exchange"
+                            new_score = self._model.exchange_values(backarc)[-1]
+                            if new_score > best_score:
+                                inner_obj["b"] = backarc.id
+                                best_score = new_score
             cycles.append(inner_obj)
         obj = {
             "cycle": cycles,
@@ -198,6 +218,7 @@ class UKJson:
             "all_cycles": {
                 modelled.exchange.id: self._cycle(modelled.exchange)
                 for modelled in self._solution.possible
+                if len(modelled.exchange) >= 2
             }
         }
         obj["exchange_data"] = [
