@@ -203,7 +203,7 @@ def UK_age_score(d1: Donor, d2: Donor) -> tuple[float, float]:
     _age_diff_factor = 1e-5
     _max_age_diff = 70
 
-    if d1.NDD:
+    if d2.NDD:
         return 0, 0
     bonus = 0
     age_diff = abs(d1.age - d2.age)
@@ -221,11 +221,11 @@ class UKScore(Objective):
         pass
 
     def value(self, graph: CompatibilityGraph, exchange: Exchange) -> float:
-        """What is the score (UK) of this exchange?
+        """What is the UK score of this exchange?
 
         :param graph: The graph containing the exchange
         :param exchange: An exchange
-        :return: The number of backarcs in the exchange
+        :return: The UK score of this exchange
         """
         score: float = 0.0
         for ind, source in enumerate(exchange):
@@ -241,7 +241,7 @@ class UKScore(Objective):
                 score += transplant.weight
                 bonus, tb = UK_age_score(donor, target_v.donor)
                 score += bonus + tb
-        return score
+        return round(score, 5)
 
     def describe(self) -> str:
         """Describes what this objective optimises.
