@@ -250,17 +250,59 @@ def test_threeway_count_test3b(test3b_graph):
 
 def test_threeway_count_test5(test5_graph):
     obj = model.ThreeWay()
+    cycles = test5_graph.findCycles(3)
     chains = test5_graph.findChains(3)
     checked = 0
-    for chain in chains:
-        indices = [int(v.donor.id) for v in chain]
+    for exchange in chains + cycles:
+        indices = [int(v.donor.id) for v in exchange]
         if indices == [1, 2]:
-            assert obj.value(test5_graph, chain) == 0
+            assert obj.value(test5_graph, exchange) == 0
+            checked += 1
+        if indices == [3, 4]:
+            assert obj.value(test5_graph, exchange) == 0
             checked += 1
         if indices == [1, 3]:
-            assert obj.value(test5_graph, chain) == 0
+            assert obj.value(test5_graph, exchange) == 0
             checked += 1
         if indices == [1, 3, 4]:
-            assert obj.value(test5_graph, chain) == 1
+            assert obj.value(test5_graph, exchange) == 1
             checked += 1
-    assert checked == 3
+    assert checked == 4
+
+
+def test_ukscore_test1(test1_graph):
+    obj = model.UKScore()
+    cycles = test1_graph.findCycles(3)
+    checked = 0
+    for cycle in cycles:
+        indices = [int(v.donor.id) for v in cycle]
+        if indices == [1, 2]:
+            assert obj.value(test1_graph, cycle) == 8.098
+            checked += 1
+        if indices == [2, 3, 4]:
+            assert obj.value(test1_graph, cycle) == 12.121
+            checked += 1
+    assert checked == 2
+
+
+def test_ukscore_test5(test5_graph):
+    obj = model.UKScore()
+    cycles = test5_graph.findCycles(3)
+    chains = test5_graph.findChains(3)
+    checked = 0
+    for exchange in chains + cycles:
+        indices = [int(v.donor.id) for v in exchange]
+        print(indices)
+        if indices == [1, 2]:
+            assert obj.value(test5_graph, exchange) == 4.049
+            checked += 1
+        if indices == [3, 4]:
+            assert obj.value(test5_graph, exchange) == 8.072
+            checked += 1
+        if indices == [1, 3]:
+            assert obj.value(test5_graph, exchange) == 4.036
+            checked += 1
+        if indices == [1, 3, 4]:
+            assert obj.value(test5_graph, exchange) == 8.072
+            checked += 1
+    assert checked == 4
